@@ -92,12 +92,12 @@ void kpCommandHistory::addCreateSelectionCommand (kpToolSelectionCreateCommand *
 void kpCommandHistory::undo ()
 {
 #if DEBUG_KP_COMMAND_HISTORY
-    kDebug () << "kpCommandHistory::undo() CALLED!";
+    qCDebug(kpLogCommands) << "kpCommandHistory::undo() CALLED!";
 #endif
     if (m_mainWindow && m_mainWindow->toolHasBegunShape ())
     {
     #if DEBUG_KP_COMMAND_HISTORY
-        kDebug () << "\thas begun shape - cancel draw";
+        qCDebug(kpLogCommands) << "\thas begun shape - cancel draw";
     #endif
         m_mainWindow->tool ()->cancelShapeInternal ();
     }
