@@ -58,9 +58,9 @@ Q_OBJECT
 
 public:
     kpToolSelectionResizeScaleCommand (kpCommandEnvironment *environ);
-    virtual ~kpToolSelectionResizeScaleCommand ();
+    ~kpToolSelectionResizeScaleCommand () override;
 
-    kpCommandSize::SizeType size () const Q_DECL_OVERRIDE;
+    kpCommandSize::SizeType size () const override;
 
 public:
     const kpAbstractSelection *originalSelection () const;
@@ -91,8 +91,8 @@ public:
     void finalize ();
 
 public:
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
 protected:
     kpAbstractSelection *m_originalSelectionPtr;
